@@ -11,6 +11,11 @@ from .main import main
 @click.option('--log-level', '-l', default=logging.INFO, show_default=True,
               type=click.INT, help='Debugging log level.')
 def cmd(name: str, log_level: int):
+  # click doesn't allow optionals and coerces None into a string
+  print(type(name), name)
+  if name == 'NoneType': 
+    name = None
+
   main(name, log_level)
 
 
