@@ -1,3 +1,4 @@
+from typing import Optional
 import logging
 import sys
 
@@ -8,12 +9,15 @@ from .adapter import ChromecastAdapter
 from .listeners import register_mpris_adapter
 
 
-def create_adapters_and_server(chromecast_name: str) -> Server:
-  chromecast = get_chromecast(chromecast_name)
+def create_adapters_and_server(chromecast_name: Optional[str]) -> Optional[Server]:
+  if chromecast_name:
+    chromecast = get_chromecast(chromecast_name)
+  
+  else:
+    chromecast = get_chromecast()
 
   if not chromecast:
-    logging.warning("Chromecast not found.")
-    sys.exit(RC_NO_CHROMECAST)
+    return
 
   chromecast_adapter = ChromecastAdapter(chromecast)
   mpris = Server(name=chromecast.name, adapter=chromecast_adapter)
@@ -24,15 +28,16 @@ def create_adapters_and_server(chromecast_name: str) -> Server:
   return mpris
 
 
-def main(name: str, log_level: int = logging.INFO):
+def main(name: Optional[str], log_level: int = logging.INFO):
   logging.basicConfig(level=log_level)
-
   mpris = create_adapters_and_server(name)
+
+  if not mpris:
+    logging.warning("Chromecast not found.")
+    sys.exit(RC_NO_CHROMECAST)
+
   mpris.loop()
 
 
 if __name__ == "__main__":
-  # from dbus.mainloop.glib import DBusGMainLoop
-  # DBusGMainLoop(set_as_default=True)
-
   main(sys.argv[1])
